"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _clientSqs = require("@webiny/aws-sdk/client-sqs");
var _chunk = _interopRequireDefault(require("lodash/chunk"));
var _handlerAws = require("@webiny/handler-aws");
var _utils = require("@webiny/utils");
var _default = params => {
  const {
    storageOperations
  } = params;
  const sqsClient = new _clientSqs.SQSClient();
  return (0, _handlerAws.createEventBridgeEventHandler)(async ({
    payload
  }) => {
    if (payload["detail-type"] !== "RenderPages") {
      return;
    }
    const event = payload.detail;
    const variant = event.variant;

    // Check if a specific variant rerender is requested.
    if (variant && variant !== process.env.STAGED_ROLLOUTS_VARIANT) {
      return;
    }
    const settings = await storageOperations.getSettings();
    if (!settings.sqsQueueUrl) {
      console.error("SQS Queue URL was not found in Prerendering Settings!");
      return;
    }
    const toRender = [];

    // Event might contain specific paths to exclude from full rerender.
    const exclude = event.exclude || [];
    let tenants = [event.tenant];
    if (event.tenant === "*") {
      // If `*` is passed, we need to process this event on all tenants.
      tenants = await storageOperations.getTenantIds();
    }
    for (const tenant of tenants) {
      if (event.path === "*") {
        const renders = await storageOperations.listRenders({
          where: {
            tenant
          }
        });
        renders.forEach(addRender);
      } else if (event.tag) {
        const renders = await storageOperations.listRenders({
          where: {
            tenant,
            tag: event.tag
          }
        });
        renders.forEach(addRender);
      } else {
        addRender({
          ...event,
          tenant
        });
      }
    }
    const entries = [];
    for (const item of toRender) {
      const messageId = (0, _utils.generateId)(8);
      entries.push({
        // A batch entry ID can only contain alphanumeric characters, hyphens and underscores.
        Id: messageId,
        // MessageBody is a string, so we stringify the payload.
        MessageBody: JSON.stringify(item.body),
        // We're using the same unique ID as the message itself. For now, we don't want to deduplicate anything.
        MessageDeduplicationId: messageId,
        // We're grouping messages using the DB namespace, which looks like this: `T#root` (group by tenant).
        MessageGroupId: item.groupId
      });
    }
    const entriesChunked = (0, _chunk.default)(entries, 10);
    for (const chunk of entriesChunked) {
      const result = await sqsClient.send(new _clientSqs.SendMessageBatchCommand({
        QueueUrl: settings.sqsQueueUrl,
        Entries: chunk
      }));
      if (result.Failed?.length) {
        console.error("Failed to deliver some of messages");
        console.error(JSON.stringify(result.Failed));
      }
    }
    function addRender(render) {
      if (render.path && exclude.includes(render.path)) {
        return;
      }

      /**
       * We're only sending the data that comes from the business logic. Things like CDN URLs, S3 buckets, etc.
       * are all injected into the appropriate Lambda functions at deploy time, so that information is detached from
       * the database. This way we are sure that we don't store obsolete infrastructure information.
       */
      toRender.push({
        groupId: render.groupId ?? render.tenant,
        body: render
      });
    }
  });
};
exports.default = _default;

//# sourceMappingURL=subscriber.js.map